// Filter for properly formatting currency.
angular.module('app', []).filter('customcurrency', function(numberFilter) {
    return function(amount, currencyISO) {

        // Define all currencies and their differences.
        var currencies = {
            "EUR": {
                thousandSeparator: '.',
                decimalSeparator: ',',
                symbol: '€',
                symbolIsPrefix: true
            },
            "USD": {
                thousandSeparator: ',',
                decimalSeparator: '.',
                symbol: '$',
                symbolIsPrefix: true
            },
            "SEK": {
                thousandSeparator: ' ',
                decimalSeparator: '.',
                symbol: 'kr',
                symbolIsPrefix: false
            }
        }

        // Round the number using Angular's built-in number filter.
        var strAmount = numberFilter(amount, 2);

        // Replace the default separators with letters to identify them.
        strAmount = strAmount.replace(/\,/g, "T");
        strAmount = strAmount.replace(/\./g, "D");

        // Replace the letters with the correct separator.
        strAmount = strAmount.replace(/T/g, currencies[currencyISO].thousandSeparator);
        strAmount = strAmount.replace(/D/g, currencies[currencyISO].decimalSeparator);

        // Apply the symbol.
        if (currencies[currencyISO].symbolIsPrefix) {
            strAmount = currencies[currencyISO].symbol + strAmount;
        } else {
            strAmount = strAmount + ' ' + currencies[currencyISO].symbol;
        }

        return strAmount;

    };
});
