﻿using Ch20.Models;
using System;
using System.Collections.Generic;
using System.Runtime.Caching;
using System.Web.UI;

namespace Ch20
{
    public partial class Default : Page
    {
        public List<Artist> ArtistCache
        {
            get { return (List<Artist>)MemoryCache.Default.Get("artists"); }
            set { MemoryCache.Default.Set("artists", value, ObjectCache.InfiniteAbsoluteExpiration); }
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                if (ArtistCache == null)
                {
                    ArtistCache = new List<Artist>();
                }
            }

            BindArtistsRepeater();
        }

        protected void btnAdd_Click(object sender, EventArgs e)
        {
            string artistName = txtName.Text;
            if (string.IsNullOrEmpty(artistName))
            {
                lblError.Text = "Invalid artist name: cannot be empty.";
                return;
            }

            string rating = txtRating.Text;
            if (string.IsNullOrEmpty(rating))
            {
                lblError.Text = "Invalid artist rating: cannot be empty.";
                return;
            }
            
            int ratingNum;
            if (!int.TryParse(rating, out ratingNum))
            {
                lblError.Text = "Invalid artist rating: must be a number.";
                return;
            }

            ArtistCache.Add(new Artist {
                Id = Guid.NewGuid(),
                Name = artistName,
                Rating = ratingNum
            });

            txtName.Text = null;
            txtRating.Text = null;

            BindArtistsRepeater();
            lblError.Text = null;
        }

        private void BindArtistsRepeater()
        {
            rptArtists.DataSource = ArtistCache;
            rptArtists.DataBind();
        }
    }
}